# CheapAdmin by David Bowland
# ./addons/eventscripts/cheapadmin/cheapadmin.py

import cmdlib
import es
import services

# Import CheapPopup

from cheappopup import *

# This CheapPopup object is unique to our addon
# It allows us to control our popups without having to worry about
# intefering with the popups of other addons
popup = CheapPopup()

###

# This event is out of order for demonstration purposes
def unload():
   # We need to do this with our CheapPopup object or it will hang around
   # after our addon is gone
   popup.unload()

   # We also want to unregister our commands
   cmdlib.unregisterSayCommand('!admin')
   cmdlib.unregisterSayCommand('!kick')
   cmdlib.unregisterSayCommand('!ban')

###

auth = services.use('auth')
auth.registerCapability('cheapadmin_immune', auth.POWERUSER) # Players immune from kick/ban


def getUseridList(excludeid):
   """ Generator that yields userids of kick- or ban-able players """
   for userid in es.getUseridList():
      if (userid != excludeid and # If it's not the player to exclude
       es.getplayersteamid(userid) != 'BOT' and # The player isn't a bot
       not auth.isUseridAuthorized(userid, 'cheapadmin_immune')): # The player isn't immune
         yield userid # This userid will show up in our menu
   raise StopIteration # Tells Python we have no more elements in this generator

###

""" Main menu """

def mainMenu(userid, args=None):
   # Send our popup by supplying direct text
   popup.sendMenu(userid, 0, # duration = 0 (until selection)
    'CheapAdmin menu:' +
    '\n ' +
    '\n->6. Kick menu' + # Start with 6 because it's hard to accidentally hit
    '\n ' +
    '\n->8. Ban menu' +
    '\n ' +
    '\n0. Exit',
    mainMenuSelect) # This function will be called with the selection

cmdlib.registerSayCommand('!admin', mainMenu, 'CheapAdmin main menu',
 'cheapadmin_admin', 'ADMIN')


def mainMenuSelect(userid, item):
   if item == 6:
      # Send the kick menu
      kickMenu(userid)

   elif item == 8:
      # Send the ban menu
      banMenu(userid)
   # Any other item just exits

###

# This contains the language strings for the kick selection menu
kickmenulang = SelectionLanguages()
kickmenulang.header = 'Select player to kick:'
kickmenulang.noselections = 'No kickable players'
# The following values are default values presented for demonstration
kickmenulang.separator1 = ' '
kickmenulang.separator2 = ' '
kickmenulang.back = 'Back'
kickmenulang.next = 'Next'
kickmenulang.firstback = 'Last page'
kickmenulang.lastnext = 'First page'
kickmenulang.exit = 'Exit'

def kickMenu(userid, args=None):
   if args is None: # If this is being called from mainMenuSelect
      # We can go back
      kickmenulang.firstback = 'Main menu'
      firstback = mainMenu
   else: # The first "back" selection will take the user to the last page
      kickmenulang.firstback = 'Last page'
      firstback = None

   # Compile a dictionary for item selection
   # We display the player names (keys) and return to kickMenuSelect userids (values)
   items = dict((es.getplayername(x), x) for x in getUseridList(userid))
   # Send selection popup
   popup.sendSelectionMenu(userid, items, kickMenuSelect, kickmenulang, firstback)

# We can get to the kick menu directly
cmdlib.registerSayCommand('!kick', kickMenu, 'CheapAdmin kick menu',
 'cheapadmin_kickonly', 'POWERUSER') # Power users can kick but not ban


def kickMenuSelect(userid, item):
   if item is None: # No selection
      return
   elif es.getuserid(item): # If the player is still connected
      es.server.kickid(item) # Kick the player

###

# This contains the language strings for the ban selection menu
banmenulang = SelectionLanguages()
banmenulang.header = 'Select player to ban:'
banmenulang.noselections = 'No banable players'

def banMenu(userid, args=None):
   if args is None: # If this is being called from mainMenuSelect
      # We can go back
      banmenulang.firstback = 'Main menu'
      firstback = mainMenu
   else: # The first "back" selection will take the user to the last page
      banmenulang.firstback = 'Last page'
      firstback = None

   items = dict((es.getplayername(x), x) for x in getUseridList(userid))
   popup.sendSelectionMenu(userid, items, banMenuSelect, banmenulang, firstback)

# We can get to the ban menu directly
cmdlib.registerSayCommand('!ban', banMenu, 'CheapAdmin ban menu',
 'cheapadmin_admin', 'ADMIN')


def banMenuSelect(userid, item):
   if item is None:
      return
   elif es.getuserid(item):
      es.server.banid(0, item, 'kick') # Kick and perm ban player
      es.server.writeid()